==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/en/globals.php <==
<?php
regGS("Account", "Account");
regGS("Items per page", "Items per page");
regGS("Cannot create file \"$1\"", "Cannot create file \"$1\"");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" is invalid or is not an image.");
regGS("URL \"$1\" is not an image.", "URL \"$1\" is not an image.");
regGS("Add new", "Add new");
regGS("CAMPSITE", "CAMPSITE");
regGS("Home", "Home");
regGS("Logout", "Logout");
regGS("You are logged in as $1", "You are logged in as $1");
regGS("More...", "More...");
regGS("Content", "Content");
regGS("Languages", "Languages");
regGS("Countries", "Countries");
regGS("Templates", "Templates");
regGS("Topics", "Topics");
regGS("Configure", "Configure");
regGS("Image Archive", "Image Archive");
regGS("Add Article", "Add Article");
regGS("Fields", "Fields");
regGS("Delete", "Delete");
regGS("Type", "Type");
regGS("Name", "Name");
regGS("Keyword", "Keyword");
regGS("Native name", "Native name");
regGS("Code", "Code");
regGS("Code page", "Code page");
regGS("Edit", "Edit");
regGS("Reader", "Reader");
regGS("Access", "Access");
regGS("Login", "Login");
regGS("Password", "Password");
regGS("Site", "Site");
regGS("Currency", "Currency");
regGS("Path", "Path");
regGS("Go up", "Go up");
regGS("URL", "URL");
regGS("Order", "Order");
regGS("Hide", "Hide");
regGS("Duplicate", "Duplicate");
regGS("Insert Internal Link", "Insert Internal Link");
regGS("Subscription", "Subscription");
regGS("expires", "expires");
regGS("starts", "starts");
regGS("before", "before");
regGS("after", "after");
regGS("on", "on");
regGS("status", "status");
regGS("active", "active");
regGS("inactive", "inactive");
regGS("Subscribers", "Subscribers");
regGS("Staff", "Staff");
regGS("Select destination", "Select destination");
regGS("No languages", "No languages");
regGS("---Select language---", "---Select language---");
regGS("No publications", "No publications");
regGS("---Select publication---", "---Select publication---");
regGS("No issues", "No issues");
regGS("---Select issue---", "---Select issue---");
regGS("No sections", "No sections");
regGS("---Select section---", "---Select section---");
regGS("No articles", "No articles");
regGS("---Select article---", "---Select article---");
regGS("Language", "Language");
regGS("Translation", "Translation");
regGS("Country", "Country");
regGS("Account name", "Account name");
regGS("Definition", "Definition");
regGS("Publication", "Publication");
regGS("Default language", "Default language");
regGS("Time Unit", "Time Unit");
regGS("Unit Cost", "Unit Cost");
regGS("Subscriptions", "Subscriptions");
regGS("Issue", "Issue");
regGS("Number", "Number");
regGS("Section", "Section");
regGS("Keywords", "Keywords");
regGS("Topic", "Topic");
regGS("URL Name", "URL Name");
regGS("Left to pay", "Left to pay");
regGS("Active", "Active");
regGS("Paid", "Paid");
regGS("Trial", "Trial");
regGS("Next", "Next");
regGS("Previous", "Previous");
regGS("Translate", "Translate");
regGS("Details", "Details");
regGS("View", "View");
regGS("Scheduled Publishing", "Scheduled Publishing");
regGS("Time", "Time");
regGS("Action", "Action");
regGS("Schedule a new action", "Schedule a new action");
regGS("No entries.", "No entries.");
regGS("Scheduling a new publish action", "Scheduling a new publish action");
regGS("Delete scheduled publish action", "Delete scheduled publish action");
regGS("The $1 action has been scheduled on $2", "The $1 action has been scheduled on $2");
regGS("Date/Time", "Date/Time");
regGS("You must select an action.", "You must select an action.");
regGS("There was an error scheduling the $1 action on $2", "There was an error scheduling the $1 action on $2");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "You do not have the right to schedule issues or articles for automatic publishing.");
regGS("The action scheduled on $1 could not be deleted.", "The action scheduled on $1 could not be deleted.");
regGS("Front page", "Front page");
regGS("Section page", "Section page");
regGS("Show on front page", "Show on front page");
regGS("Remove from front page", "Remove from front page");
regGS("Show on section page", "Show on section page");
regGS("Remove from section page", "Remove from section page");
regGS("Actions", "Actions");
regGS("Publishing", "Publishing");
regGS("Show", "Show");
regGS("Remove", "Remove");
regGS("days", "days");
regGS("Article Types", "Article Types");
regGS("Staff User Types", "Staff User Types");
regGS("Publications", "Publications");
regGS("Issues", "Issues");
regGS("Sections", "Sections");
regGS("Articles", "Articles");
regGS("Images", "Images");
regGS("Nr", "Nr");
regGS("Change", "Change");
regGS("Add new issue", "Add new issue");
regGS("Add new topic", "Add new topic");
regGS("Delete topic", "Delete topic");
regGS("Edit languages", "Edit languages");
regGS("Section Template", "Section Template");
regGS("Article Template", "Article Template");
regGS("Default Language", "Default Language");
regGS("Countries Subscription Default Time", "Countries Subscription Default Time");
regGS("Pay Period", "Pay Period");
regGS("Info", "Info");
regGS("Trial Period", "Trial Period");
regGS("Paid Period", "Paid Period");
regGS("Preview", "Preview");
regGS("You must complete the $1 field.", "You must complete the $1 field.");
regGS("Error", "Error");
regGS("Invalid input: $1", "Invalid input: $1");
regGS("Language does not exist.", "Language does not exist.");
regGS("Keyword does not exist.", "Keyword does not exist.");
regGS("Publication does not exist.", "Publication does not exist.");
regGS("Country does not exist.", "Country does not exist.");
regGS("Issue does not exist.", "Issue does not exist.");
regGS("Topic does not exist.", "Topic does not exist.");
regGS("You must select a language.", "You must select a language.");
regGS("Section does not exist.", "Section does not exist.");
regGS("No articles.", "No articles.");
regGS("Article does not exist.", "Article does not exist.");
regGS("Image does not exist.", "Image does not exist.");
regGS("Access denied", "Access denied");
regGS("There was an error reading the language parameter.", "There was an error reading the language parameter.");
regGS("There was an error reading the publication parameter.", "There was an error reading the publication parameter.");
regGS("There was an error reading the issue parameter.", "There was an error reading the issue parameter.");
regGS("There was an error reading request parameters.", "There was an error reading request parameters.");
regGS("Invalid value of user type parameter", "Invalid value of user type parameter");
regGS("Invalid article identifier", "Invalid article identifier");
regGS("Invalid destination section selected", "Invalid destination section selected");
regGS("Internal error: identifiers not initialized", "Internal error: identifiers not initialized");
regGS("Internal database error", "Internal database error");
regGS("Invalid parameters received", "Invalid parameters received");
regGS("Add new article", "Add new article");
regGS("Status", "Status");
regGS("No such article.", "No such article.");
regGS("Published", "Published");
regGS("Not published", "Not published");
regGS("Submitted", "Submitted");
regGS("New", "New");
regGS("Article", "Article");
regGS("Publish", "Publish");
regGS("Unpublish", "Unpublish");
regGS("Unlock", "Unlock");
regGS("Uploaded", "Uploaded");
regGS("(yyyy-mm-dd)", "(yyyy-mm-dd)");
regGS("YYYY-MM-DD", "YYYY-MM-DD");
regGS("Submit", "Submit");
regGS("Field", "Field");
regGS("Edit details", "Edit details");
regGS("No such image.", "No such image.");
regGS("Image", "Image");
regGS("Description", "Description");
regGS("Photographer", "Photographer");
regGS("Place", "Place");
regGS("Date", "Date");
regGS("Thumbnail", "Thumbnail");
regGS("In use", "In use");
regGS("Miscellaneous", "Miscellaneous");
regGS("Identifier", "Identifier");
regGS("Additional searches", "Additional searches");
regGS("Most Recently Added", "Most Recently Added");
regGS("Most Recently Modified", "Most Recently Modified");
regGS("$1 images found", "$1 images found");
regGS("Reset search conditions", "Reset search conditions");
regGS("Preview issue", "Preview issue");
regGS("Image number", "Image number");
regGS("Users", "Users");
regGS("User may add/change publications", "User may add/change publications");
regGS("User may delete publications", "User may delete publications");
regGS("User may add/change issues", "User may add/change issues");
regGS("User may delete issues", "User may delete issues");
regGS("User may add/change sections", "User may add/change sections");
regGS("User may delete sections", "User may delete sections");
regGS("User may add articles", "User may add articles");
regGS("User may change articles", "User may change articles");
regGS("User may delete articles", "User may delete articles");
regGS("User may add images", "User may add images");
regGS("User may change images", "User may change images");
regGS("User may delete images", "User may delete images");
regGS("User may add templates", "User may add templates");
regGS("User may delete templates", "User may delete templates");
regGS("User may add/change staff accounts and passwords", "User may add/change staff accounts and passwords");
regGS("User may add/change subscribers accounts and passwords", "User may add/change subscribers accounts and passwords");
regGS("User may delete staff accounts", "User may delete staff accounts");
regGS("User may manage user subscriptions", "User may manage user subscriptions");
regGS("User may manage account types", "User may manage account types");
regGS("User may add/change article types", "User may add/change article types");
regGS("User may delete article types", "User may delete article types");
regGS("User may manage templates", "User may manage templates");
regGS("User may add/change country entries", "User may add/change country entries");
regGS("User may add languages and manage language information", "User may add languages and manage language information");
regGS("User may delete languages", "User may delete languages");
regGS("User will be notified on several events", "User will be notified on several events");
regGS("User may view audit logs", "User may view audit logs");
regGS("User may add/change country names", "User may add/change country names");
regGS("User may delete country entries", "User may delete country entries");
regGS("User may manage localizer", "User may manage localizer");
regGS("User may manage indexer", "User may manage indexer");
regGS("User may publish articles", "User may publish articles");
regGS("User may manage topics", "User may manage topics");
regGS("User may use bold", "User may use bold");
regGS("User may use italic", "User may use italic");
regGS("User may use underline", "User may use underline");
regGS("User may use strikethrough", "User may use strikethrough");
regGS("User may change text alignment", "User may change text alignment");
regGS("User may copy, cut, and paste", "User may copy, cut, and paste");
regGS("User may undo/redo", "User may undo/redo");
regGS("User may change text direction", "User may change text direction");
regGS("User may set indents", "User may set indents");
regGS("User may add links", "User may add links");
regGS("User may add subheads", "User may add subheads");
regGS("User may insert images", "User may insert images");
regGS("User may view the HTML source", "User may view the HTML source");
regGS("User may enlarge the editor", "User may enlarge the editor");
regGS("User may change the font face", "User may change the font face");
regGS("User may change the font size", "User may change the font size");
regGS("User may create bulleted lists", "User may create bulleted lists");
regGS("User may create numbered lists", "User may create numbered lists");
regGS("User may insert tables", "User may insert tables");
regGS("User may insert horizontal rules", "User may insert horizontal rules");
regGS("User may change the font color", "User may change the font color");
regGS("User may use superscripts", "User may use superscripts");
regGS("User may use subscripts", "User may use subscripts");
regGS("User may restart the template engine", "User may restart the template engine");
regGS("Administrative tasks", "Administrative tasks");
regGS("Restart the template engine", "Restart the template engine");
regGS("The template engine was (re)started.", "The template engine was (re)started.");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "The template engine could not be restarted! Please verify if the template engine was started by other user than $1.");
regGS("An user type with the name '$1' already exists.", "An user type with the name '$1' already exists.");
regGS("Localizer", "Localizer");
regGS("Staff/Subscribers Management", "Staff/Subscribers Management");
regGS("Editor Basic Settings", "Editor Basic Settings");
regGS("Editor Advanced Font Settings", "Editor Advanced Font Settings");
regGS("Editor Table Settings", "Editor Table Settings");
regGS("Editor Miscellaneous Settings", "Editor Miscellaneous Settings");
regGS("Updating user types permissions", "Updating user types permissions");
regGS("Adding new translation", "Adding new translation");
regGS("No more languages.", "No more languages.");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "The $1 field may only contain letters, digits and underscore (_) character.");
regGS("Add new publication", "Add new publication");
regGS("Upload new template", "Upload new template");
regGS("Add new staff member", "Add new staff member");
regGS("Add new subscriber", "Add new subscriber");
regGS("Add new user type", "Add new user type");
regGS("Add new article type", "Add new article type");
regGS("Add new country", "Add new country");
regGS("Add new language", "Add new language");
regGS("Add new section", "Add new section");
regGS("View logs", "View logs");
regGS("Change your password", "Change your password");
regGS("Your articles", "Your articles");
regGS("Submitted articles", "Submitted articles");
regGS("Logs", "Logs");
regGS("There are $1 article(s) left.", "There are $1 article(s) left.");
regGS("There are $1 issues(s) left.", "There are $1 issues(s) left.");
regGS("There are $1 section(s) left.", "There are $1 section(s) left.");
regGS("There are $1 publication(s) left.", "There are $1 publication(s) left.");
regGS("There are $1 keywords(s) left.", "There are $1 keywords(s) left.");
regGS("There are $1 countries left.", "There are $1 countries left.");
regGS("Name <SMALL>(click to edit)</SMALL>", "Name <SMALL>(click to edit)</SMALL>");
regGS("User account", "User account");
regGS("No such user account.", "No such user account.");
regGS("Add new subscription", "Add new subscription");
regGS("You do not have the right to add subscriptions.", "You do not have the right to add subscriptions.");
regGS("Adding subscription", "Adding subscription");
regGS("The section could not be added.", "The section could not be added.");
regGS("Delete subscription", "Delete subscription");
regGS("You do not have the right to delete subscriptions.", "You do not have the right to delete subscriptions.");
regGS("No such subscription.", "No such subscription.");
regGS("The section $1 could not be deleted.", "The section $1 could not be deleted.");
regGS("The topic $1 could not be deleted.", "The topic $1 could not be deleted.");
regGS("Yes", "Yes");
regGS("No", "No");
regGS("Close", "Close");
regGS("No issues.", "No issues.");
regGS("No subscriptions.", "No subscriptions.");
regGS("Back to Edit Article", "Back to Edit Article");
regGS("Adding new topic", "Adding new topic");
regGS("Topic $1 added", "Topic $1 added");
regGS("The topic could not be added.", "The topic could not be added.");
regGS("Add another topic", "Add another topic");
regGS("Deleting topic", "Deleting topic");
regGS("There are $1 subtopics left.", "There are $1 subtopics left.");
regGS("Topic $1 deleted", "Topic $1 deleted");
regGS("You do not have the right to change topic name.", "You do not have the right to change topic name.");
regGS("Topic $1 updated", "Topic $1 updated");
regGS("The topic name could not be updated.", "The topic name could not be updated.");
regGS("Change topic name", "Change topic name");
regGS("Delete topic $1", "Delete topic $1");
regGS("No topics", "No topics");
regGS("The topic $1 has been deleted.", "The topic $1 has been deleted.");
regGS("There are $1 articles using the topic.", "There are $1 articles using the topic.");
regGS("You must fill in the $1 field.", "You must fill in the $1 field.");
regGS("You do not have the right to add articles.", "You do not have the right to add articles.");
regGS("Start", "Start");
regGS("Days", "Days");
regGS("(YYYY-MM-DD)", "(YYYY-MM-DD)");
regGS("The sections were added successfully.", "The sections were added successfully.");
regGS("The sections could not be added successfully. Some of them were already added !", "The sections could not be added successfully. Some of them were already added !");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "This article cannot be previewed. Please make sure it has the article template selected.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "This article cannot be previewed. Please make sure it has the front page template selected.");
regGS("Add another", "Add another");
regGS("Cancel", "Cancel");
regGS("Done", "Done");
regGS("New Field", "New Field");
regGS("OK", "OK");
regGS("Save", "Save");
regGS("Search", "Search");
regGS("Add New Field", "Add New Field");
regGS("Make a selection", "Make a selection");
regGS("You must input a number greater than 0 into the $1 field.", "You must input a number greater than 0 into the $1 field.");
regGS("You must input a valid date.", "You must input a valid date.");
regGS("Add new field", "Add new field");
regGS("Article automatic publishing schedule", "Article automatic publishing schedule");
regGS("Are you sure you want to delete this scheduled action?", "Are you sure you want to delete this scheduled action?");
regGS("Unlink", "Unlink");
regGS("Are you sure you want to delete the image \'$1\'?", "Are you sure you want to delete the image \'$1\'?");
regGS("No such issue.", "No such issue.");
regGS("No such section.", "No such section.");
regGS("Are you sure you want to delete the subscription to the publication $1?", "Are you sure you want to delete the subscription to the publication $1?");
regGS("Are you sure you want to deactivate the subscription?", "Are you sure you want to deactivate the subscription?");
regGS("Are you sure you want to activate the subscription?", "Are you sure you want to activate the subscription?");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.");
regGS("GB", "GB");
regGS("MB", "MB");
regGS("KB", "KB");
regGS("bytes", "bytes");
regGS("Attach", "Attach");
regGS("Back", "Back");
regGS("File", "File");
regGS("Save and Close", "Save and Close");
regGS("Add", "Add");
?>

==> campsite-2.6.7_5.tbz: campsite/www-common/html/priv/lang/en/globals.php <==
<?php 
regGS("Account", "Account");
regGS("Items per page", "Items per page");
regGS("Add new", "Add new");
regGS("Campsite", "Campsite");
regGS("Home", "Home");
regGS("Logout", "Logout");
regGS("More...", "More...");
regGS("Content", "Content");
regGS("Languages", "Languages");
regGS("Countries", "Countries");
regGS("Templates", "Templates");
regGS("Topics", "Topics");
regGS("Configure", "Configure");
regGS("Image Archive", "Image Archive");
regGS("Add Article", "Add Article");
regGS("Fields", "Fields");
regGS("Delete", "Delete");
regGS("Type", "Type");
regGS("Name", "Name");
regGS("Code", "Code");
regGS("Edit", "Edit");
regGS("Login", "Login");
regGS("Password", "Password");
regGS("Site", "Site");
regGS("Path", "Path");
regGS("Go up", "Go up");
regGS("URL", "URL");
regGS("Order", "Order");
regGS("Hide", "Hide");
regGS("Duplicate", "Duplicate");
regGS("Subscription", "Subscription");
regGS("expires", "expires");
regGS("starts", "starts");
regGS("before", "before");
regGS("after", "after");
regGS("on", "on");
regGS("status", "status");
regGS("active", "active");
regGS("inactive", "inactive");
regGS("Subscribers", "Subscribers");
regGS("Staff", "Staff");
regGS("Select destination", "Select destination");
regGS("No languages", "No languages");
regGS("---Select language---", "---Select language---");
regGS("No publications", "No publications");
regGS("---Select publication---", "---Select publication---");
regGS("No issues", "No issues");
regGS("---Select issue---", "---Select issue---");
regGS("No sections", "No sections");
regGS("---Select section---", "---Select section---");
regGS("No articles", "No articles");
regGS("---Select article---", "---Select article---");
regGS("Language", "Language");
regGS("Country", "Country");
regGS("Account name", "Account name");
regGS("Publication", "Publication");
regGS("Default language", "Default language");
regGS("Subscriptions", "Subscriptions");
regGS("Issue", "Issue");
regGS("Number", "Number");
regGS("Section", "Section");
regGS("Keywords", "Keywords");
regGS("Topic", "Topic");
regGS("URL Name", "URL Name");
regGS("Left to pay", "Left to pay");
regGS("Active", "Active");
regGS("Trial", "Trial");
regGS("Next", "Next");
regGS("Previous", "Previous");
regGS("Translate", "Translate");
regGS("View", "View");
regGS("Scheduled Publishing", "Scheduled Publishing");
regGS("Time", "Time");
regGS("Action", "Action");
regGS("Schedule a new action", "Schedule a new action");
regGS("Scheduling a new publish action", "Scheduling a new publish action");
regGS("Delete scheduled publish action", "Delete scheduled publish action");
regGS("Date/Time", "Date/Time");
regGS("You must select an action.", "You must select an action.");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "You do not have the right to schedule issues or articles for automatic publishing.");
regGS("Front page", "Front page");
regGS("Section page", "Section page");
regGS("Show on front page", "Show on front page");
regGS("Remove from front page", "Remove from front page");
regGS("Show on section page", "Show on section page");
regGS("Remove from section page", "Remove from section page");
regGS("Actions", "Actions");
regGS("Publishing", "Publishing");
regGS("Show", "Show");
regGS("Remove", "Remove");
regGS("Article Types", "Article Types");
regGS("Staff User Types", "Staff User Types");
regGS("Publications", "Publications");
regGS("Issues", "Issues");
regGS("Sections", "Sections");
regGS("Articles", "Articles");
regGS("Images", "Images");
regGS("Change", "Change");
regGS("Add new issue", "Add new issue");
regGS("Section Template", "Section Template");
regGS("Article Template", "Article Template");
regGS("Default Language", "Default Language");
regGS("Paid Period", "Paid Period");
regGS("Preview", "Preview");
regGS("You must complete the $1 field.", "You must complete the $1 field.");
regGS("Error", "Error");
regGS("Invalid input: $1", "Invalid input: $1");
regGS("Language does not exist.", "Language does not exist.");
regGS("Publication does not exist.", "Publication does not exist.");
regGS("Issue does not exist.", "Issue does not exist.");
regGS("You must select a language.", "You must select a language.");
regGS("Section does not exist.", "Section does not exist.");
regGS("No articles.", "No articles.");
regGS("Article does not exist.", "Article does not exist.");
regGS("Image does not exist.", "Image does not exist.");
regGS("Access denied", "Access denied");
regGS("Invalid parameters received", "Invalid parameters received");
regGS("Add new article", "Add new article");
regGS("Status", "Status");
regGS("Published", "Published");
regGS("Not published", "Not published");
regGS("Submitted", "Submitted");
regGS("New", "New");
regGS("Article", "Article");
regGS("Publish", "Publish");
regGS("Unpublish", "Unpublish");
regGS("Unlock", "Unlock");
regGS("Uploaded", "Uploaded");
regGS("(yyyy-mm-dd)", "(yyyy-mm-dd)");
regGS("YYYY-MM-DD", "YYYY-MM-DD");
regGS("Submit", "Submit");
regGS("Image", "Image");
regGS("Description", "Description");
regGS("Photographer", "Photographer");
regGS("Place", "Place");
regGS("Date", "Date");
regGS("Thumbnail", "Thumbnail");
regGS("In use", "In use");
regGS("Additional searches", "Additional searches");
regGS("Most Recently Added", "Most Recently Added");
regGS("Most Recently Modified", "Most Recently Modified");
regGS("$1 images found", "$1 images found");
regGS("Reset search conditions", "Reset search conditions");
regGS("Image number", "Image number");
regGS("Users", "Users");
regGS("Restart the template engine", "Restart the template engine");
regGS("The template engine was (re)started.", "The template engine was (re)started.");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "The template engine could not be restarted! Please verify if the template engine was started by other user than $1.");
regGS("Localizer", "Localizer");
regGS("Adding new translation", "Adding new translation");
regGS("No more languages.", "No more languages.");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "The $1 field may only contain letters, digits and underscore (_) character.");
regGS("Add new publication", "Add new publication");
regGS("Upload new template", "Upload new template");
regGS("Add new staff member", "Add new staff member");
regGS("Add new subscriber", "Add new subscriber");
regGS("Add new user type", "Add new user type");
regGS("Add new article type", "Add new article type");
regGS("Add new country", "Add new country");
regGS("Add new language", "Add new language");
regGS("View logs", "View logs");
regGS("Change your password", "Change your password");
regGS("Your Articles", "Your Articles");
regGS("Submitted Articles", "Submitted Articles");
regGS("Logs", "Logs");
regGS("There are $1 article(s) left.", "There are $1 article(s) left.");
regGS("There are $1 issues(s) left.", "There are $1 issues(s) left.");
regGS("There are $1 section(s) left.", "There are $1 section(s) left.");
regGS("There are $1 publication(s) left.", "There are $1 publication(s) left.");
regGS("There are $1 countries left.", "There are $1 countries left.");
regGS("Name <SMALL>(click to edit)</SMALL>", "Name <SMALL>(click to edit)</SMALL>");
regGS("Add new subscription", "Add new subscription");
regGS("You do not have the right to add subscriptions.", "You do not have the right to add subscriptions.");
regGS("Adding subscription", "Adding subscription");
regGS("Delete subscription", "Delete subscription");
regGS("You do not have the right to delete subscriptions.", "You do not have the right to delete subscriptions.");
regGS("No such subscription.", "No such subscription.");
regGS("Yes", "Yes");
regGS("No", "No");
regGS("Close", "Close");
regGS("No issues.", "No issues.");
regGS("Back to Edit Article", "Back to Edit Article");
regGS("No topics", "No topics");
regGS("You must fill in the $1 field.", "You must fill in the $1 field.");
regGS("You do not have the right to add articles.", "You do not have the right to add articles.");
regGS("Start", "Start");
regGS("Days", "Days");
regGS("(YYYY-MM-DD)", "(YYYY-MM-DD)");
regGS("The sections could not be added successfully. Some of them were already added !", "The sections could not be added successfully. Some of them were already added !");
regGS("Add another", "Add another");
regGS("Cancel", "Cancel");
regGS("Done", "Done");
regGS("OK", "OK");
regGS("Save", "Save");
regGS("Search", "Search");
regGS("Make a selection", "Make a selection");
regGS("You must input a number greater than 0 into the $1 field.", "You must input a number greater than 0 into the $1 field.");
regGS("You must input a valid date.", "You must input a valid date.");
regGS("Add new field", "Add new field");
regGS("Article automatic publishing schedule", "Article automatic publishing schedule");
regGS("Are you sure you want to delete this scheduled action?", "Are you sure you want to delete this scheduled action?");
regGS("Unlink", "Unlink");
regGS("Are you sure you want to delete the image \'$1\'?", "Are you sure you want to delete the image \'$1\'?");
regGS("No such issue.", "No such issue.");
regGS("Are you sure you want to delete the subscription to the publication $1?", "Are you sure you want to delete the subscription to the publication $1?");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.");
regGS("GB", "GB");
regGS("MB", "MB");
regGS("KB", "KB");
regGS("bytes", "bytes");
regGS("Attach", "Attach");
regGS("Back", "Back");
regGS("File", "File");
regGS("Save and Close", "Save and Close");
regGS("Add", "Add");
regGS("Select All", "Select All");
regGS("Select None", "Select None");
regGS("Add Event", "Add Event");
regGS("N/A", "N/A");
regGS("On Front Page", "On Front Page");
regGS("On Section Page", "On Section Page");
regGS("Created by", "Created by");
regGS("Creation date", "Creation date");
regGS("Publication List", "Publication List");
regGS("Issue List", "Issue List");
regGS("Section List", "Section List");
regGS("All", "All");
regGS("duplicate", "duplicate");
regGS("move", "move");
regGS("Move", "Move");
regGS("From:", "From:");
regGS("Date:", "Date:");
regGS("Hidden", "Hidden");
regGS("Comments", "Comments");
regGS("Comment", "Comment");
regGS("Approved", "Approved");
regGS("Comment:", "Comment:");
regGS("Subject:", "Subject:");
regGS("Subject", "Subject");
regGS("Name:", "Name:");
regGS("IP address:", "IP address:");
regGS("Email:", "Email:");
regGS("Author:", "Author:");
regGS("Author", "Author");
regGS("Article name", "Article name");
regGS("Hide article", "Hide article");
regGS("Show article", "Show article");
regGS("Article Type Fields", "Article Type Fields");
regGS("Article Images", "Article Images");
regGS("Log Messages", "Log Messages");
regGS("Article Files", "Article Files");
regGS("Article Comments", "Article Comments");
regGS("Are you sure you want to deactivate the subscription?", "Are you sure you want to deactivate the subscription?");
regGS("Are you sure you want to activate the subscription?", "Are you sure you want to activate the subscription?");
regGS("Other", "Other");
regGS("Time:", "Time:");
regGS("No events.", "No events.");
regGS("Default templates", "Default templates");
regGS("System Preferences", "System Preferences");
regGS("The date must be in the future.", "The date must be in the future.");
regGS("Send", "Send");
regGS("Thank you.", "Thank you.");
regGS("Please take a minute to send us an email.", "Please take a minute to send us an email.");
regGS("(optional)", "(optional)");
regGS("The URL you entered is invalid: '$1'", "The URL you entered is invalid: '$1'");
?>
